import { __awaiter } from "tslib";
import { promises as fs } from "fs";
import path from "path";
import Image from "next/image";
import { z } from "zod";
import { columns } from "./components/columns";
import { DataTable } from "./components/data-table";
import { taskSchema } from "./data/schema";
import React from "react";
export const metadata = {
    title: "Tasks",
    description: "A task and issue tracker build using Tanstack Table.",
};
// Simulate a database read for tasks.
function getTasks() {
    return __awaiter(this, void 0, void 0, function* () {
        const data = yield fs.readFile(path.join(process.cwd(), "app/dashboard/data-table/data/tasks.json"));
        const tasks = JSON.parse(data.toString());
        return z.array(taskSchema).parse(tasks);
    });
}
export default function TaskPage() {
    return __awaiter(this, void 0, void 0, function* () {
        const tasks = yield getTasks();
        return (<>
      <div className="md:hidden">
        <Image src="/examples/tasks-light.png" width={1280} height={998} alt="Playground" className="block dark:hidden"/>
        <Image src="/examples/tasks-dark.png" width={1280} height={998} alt="Playground" className="hidden dark:block"/>
      </div>
      <div className="hidden h-full flex-1 flex-col space-y-8 md:flex">
        <div className="flex items-center justify-between space-y-2">
          <div>
            <h2 className="text-2xl font-bold tracking-tight">Welcome back!</h2>
            <p className="text-muted-foreground">
              Here&apos;s a list of your tasks for this month!
            </p>
          </div>
         
        </div>
        <DataTable data={tasks} columns={columns}/>
      </div>
    </>);
    });
}
