import { __awaiter } from "tslib";
import { useState, useEffect } from 'react';
import { zodResolver } from "@hookform/resolvers/zod";
import { useForm } from "react-hook-form";
import { z } from "zod";
import { Separator } from "../../../../components/ui/separator";
import { Checkbox } from "../../../../components/ui/checkbox";
import { Form } from "../../../../components/ui/form";
import { FormProvider, FuzSelect, FuzMultiButton, FuzTextField, } from "../../../../components/hook-form";
import { toast } from "../../../../components/ui/use-toast";
import { roleSchema } from '../data/schema';
import React from 'react';
// Define schema using Zod based on the ven
// Define schema using Zod based on the vendors table structure
export default function VendorForm({ defaultValue, isEdit, setShowSideNav, onRefresh, supabase }) {
    const [loader, setLoader] = useState(false);
    const [, setRole_idData] = useState(["SA", "A", "S"]);
    const [permission, setPermission] = useState({});
    const [rolesList, setRolesList] = useState([]);
    const [datas, setData] = useState({});
    const defaultValues = {
        id: (defaultValue === null || defaultValue === void 0 ? void 0 : defaultValue.id) || "",
        name: (defaultValue === null || defaultValue === void 0 ? void 0 : defaultValue.name) || "",
        type: (defaultValue === null || defaultValue === void 0 ? void 0 : defaultValue.type) || "",
        description: (defaultValue === null || defaultValue === void 0 ? void 0 : defaultValue.description) || "",
        access_level: (defaultValue === null || defaultValue === void 0 ? void 0 : defaultValue.access_level) || {},
        status: (defaultValue === null || defaultValue === void 0 ? void 0 : defaultValue.status) || "",
        is_default: (defaultValue === null || defaultValue === void 0 ? void 0 : defaultValue.is_default) || false,
        created_by: (defaultValue === null || defaultValue === void 0 ? void 0 : defaultValue.created_by) || "00000000-0000-0000-0000-000000000000",
        modified_by: (defaultValue === null || defaultValue === void 0 ? void 0 : defaultValue.modified_by) || "00000000-0000-0000-0000-000000000000",
        tenant_id: (defaultValue === null || defaultValue === void 0 ? void 0 : defaultValue.tenant_id) || '00000000-0000-0000-0000-000000000000',
        created_at: (defaultValue === null || defaultValue === void 0 ? void 0 : defaultValue.created_at) || new Date(),
        updated_at: (defaultValue === null || defaultValue === void 0 ? void 0 : defaultValue.updated_at) || new Date(),
        permissionType: undefined
    };
    const editSchema = z.object({
        name: z.string().min(1, 'Name is required'),
        permissionType: z.object({}),
        access_level: z.record(z.string()),
    });
    // Schema for other cases (when not editing)
    const defaultSchema = z.object({
        name: z.string().min(5, 'Name must be at least 5 characters long').min(1, 'Name is required'),
        access_level: z.record(z.string()),
    });
    // Define which schema to use based on the value of isEdit
    const schema = isEdit === true ? defaultSchema : editSchema;
    const form = useForm({
        resolver: zodResolver(schema),
        defaultValues,
    });
    const { setValue, watch, getValues } = form;
    const values = getValues();
    const watchValues = watch();
    console.log("values", values);
    useEffect(() => {
        console.log('permissionType', values.permissionType, watchValues === null || watchValues === void 0 ? void 0 : watchValues.permissionType);
        if (values === null || values === void 0 ? void 0 : values.permissionType) {
            let tempAcc = watchValues === null || watchValues === void 0 ? void 0 : watchValues.permissionType;
            setPermission(tempAcc);
        }
    }, [watchValues.permissionType]);
    useEffect(() => {
        const access_level = watchValues.permissionType;
        console.log("mytype", watchValues.permissionType);
        console.log("mytype", rolesList);
        if (access_level && rolesList.length > 0) {
            const filteredRoles = rolesList.filter((role) => {
                if (typeof role === 'object' && role !== null && 'access_level' in role) {
                    return role.access_level === access_level;
                }
                return false;
            });
            console.log("mytype", filteredRoles);
            if (filteredRoles.length > 0) {
                setValue('type', filteredRoles[0].type || '');
            }
            else {
                setValue('type', ''); // Set default value if no matching roles found
            }
        }
        else {
            setValue('type', ''); // Set default value if rolesList is empty or permissionType is falsy
        }
    }, [watchValues.permissionType, rolesList]);
    useEffect(() => {
        setValue('access_level', permission);
    }, [permission]);
    console.log("permission", permission);
    useEffect(() => {
        function fetchDataFromTable(tableName, setStateCallback) {
            return __awaiter(this, void 0, void 0, function* () {
                try {
                    const { data, error } = yield supabase.from('tenant').select('*');
                    if (error) {
                        console.error(`Error fetching data from ${tableName}:`, error.message);
                    }
                    else {
                        setStateCallback(data || []);
                    }
                }
                catch (err) {
                    console.error(`Error fetching data from ${tableName}:`, err);
                }
            });
        }
        fetchDataFromTable('roles', setRole_idData);
    }, []);
    useEffect(() => {
        function getRoles() {
            return __awaiter(this, void 0, void 0, function* () {
                let { data, error } = yield supabase.auth.rolesList();
                if (error) {
                    console.error("Error fetching tenants:", error.message);
                    setRolesList([]);
                }
                else {
                    console.log('rolesList', z.array(roleSchema).parse(data.role.roles));
                    setRolesList(z.array(roleSchema).parse(data.role.roles));
                }
            });
        }
        getRoles();
    }, []);
    console.log('rolesList', rolesList);
    useEffect(() => {
        var _a, _b;
        if (isEdit) {
            let tempPer = defaultValue === null || defaultValue === void 0 ? void 0 : defaultValue.access_level;
            setPermission(tempPer);
        }
        else {
            console.log("test", (_a = rolesList[0]) === null || _a === void 0 ? void 0 : _a.access_level);
            let tempAcc = rolesList && ((_b = rolesList[0]) === null || _b === void 0 ? void 0 : _b.access_level);
            console.log("tempAcc", tempAcc);
            // setPermission(tempAcc)
        }
    }, [defaultValue, rolesList]);
    function onSubmit(data) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                if (isEdit) {
                    setLoader(true);
                    console.log("datas", values);
                    const obj = Object.assign(Object.assign({}, data), { type: values.type, id: values.id, description: values.description });
                    const { error } = yield supabase.auth.updateRole(obj);
                    if (error) {
                        setTimeout(() => {
                            toast({
                                title: "Error",
                                variant: "destructive",
                                description: (<pre className="mt-2 w-[340px] rounded-md bg-slate-950 p-4">
                  <code className="text-white"> <div>
                  {JSON.stringify(error, null, 2)}
                  </div></code>
                </pre>),
                            });
                            setLoader(false);
                        }, 2000);
                    }
                    else {
                        setTimeout(() => {
                            setLoader(false);
                            form.reset();
                            toast({
                                title: "You submitted the following values:",
                                description: (<pre className="mt-2 w-[340px] rounded-md bg-slate-950 p-4">
                  <code className="text-white">Successfully Updated</code>
                </pre>),
                            });
                        }, 2000);
                        onRefresh();
                        setShowSideNav(false);
                    }
                }
                else {
                    setLoader(true);
                    console.log("datas", datas);
                    const obj = Object.assign(Object.assign({}, data), { type: values.type, description: values.description, is_default: true });
                    const { error } = yield supabase.auth.createRole(obj);
                    if (error) {
                        setTimeout(() => {
                            toast({
                                title: "Error",
                                variant: "destructive",
                                description: (<pre className="mt-2 w-[340px] rounded-md bg-slate-950 p-4">
                  <code className="text-white">Unable to create role</code>
                </pre>),
                            });
                            setLoader(false);
                        }, 2000);
                    }
                    else {
                        setTimeout(() => {
                            setLoader(false);
                            form.reset();
                            toast({
                                title: "You submitted the following values:",
                                description: (<pre className="mt-2 w-[340px] rounded-md bg-slate-950 p-4">
                  <code className="text-white">Successfully Created</code>
                </pre>),
                            });
                        }, 2000);
                        onRefresh();
                        setShowSideNav(false);
                    }
                }
            }
            catch (err) {
                console.error('Error fetching customers:', err);
            }
        });
    }
    // console.log("dataata",form.getValues())
    return (<div style={{ height: '80vh', overflowY: 'auto' }} className='px-2'> {/* Set height and overflow */}
      <Form {...form}>
        <FormProvider onSubmit={form.handleSubmit(onSubmit)} className="space-y-8">
          <div style={{ fontWeight: '700', fontSize: "20px" }}>
            {/* <h1>ROLE</h1> */}
          </div>
          <div style={{ display: 'grid', gap: '20px' }}>
            <FuzTextField label="Name" name="name" required type="character varying" placeholder="Enter Role name" form={form} maxLength={15}/>
            <FuzTextField label="Description" name="description" type="character varying" placeholder="Enter Description" form={form} maxLength={50}/>

            {/* <FuzSelect
          label="Type"
          placeholder="type"
          required
          name="type"
          options={role_idData}
          form={form}
        // displayLabel="plan_name"
        // returnLabel="id"
        /> */}
            {/* <FuzSelect
          label="Status"
          placeholder="Select Status"
          required
          name="status"
          options={status_idData}
          form={form}
        // displayLabel="plan_name"
        // returnLabel="id"
        /> */}
          </div>
          <Separator />

          {isEdit === false ? (<FuzSelect label="Role Type" placeholder="Select Role" required name="permissionType" options={rolesList} form={form} 
        //displayLabel={Object.keys(watchValues.permissionType || {}).length === 0 ? "" : "name"}
        displayLabel="name" returnLabel="access_level"/>) : null}
          <div>
          {permission && Object.entries(permission).map(([key, value], index) => (<>
  {console.log("index", index, "Key:", key, "Value:", typeof value)}
    {index === 0 && (<div className="grid grid-cols-6 items-center"> {/* Total 6 columns: 1 for the first column, 5 for the second */}
        {/* First column */}
        <div className="col-span-1"/>
        {/* Second column */}
        <div className="col-span-5">
          <div className="grid grid-cols-5 gap-4">
            {["Read", "Write", "Delete", "Import", "Export"].map((char, index) => (<div key={index} className='px-3 py-2'>
                <div className="px-3 py-3 flex items-center gap-x-2 capitalize">
                  {char}
                </div>
              </div>))}
          </div>
        </div>
      </div>)}

    <div className="grid grid-cols-6 items-center" key={key}>
      {/* First column */}
      <div className="col-span-1">
        <div className="grid grid-cols-1 gap-1">
          <div className="text-md cursor-pointer capitalize">
            {key}
          </div>
        </div>
      </div>
      {/* Second column */}
      <div className="col-span-5">
        <div className="grid grid-cols-5 gap-4">
          {[...value].map((char, index) => (<div key={index} className='px-3 py-2'>
              {/* Checkbox for each character (1 or 0) */}
              <div className="px-5 py-3 flex items-center gap-x-2">
                <Checkbox id={`${key}-${index}`} name={`${key}-${index}`} checked={char === "1"} onCheckedChange={(checked) => {
                    console.log('inside', checked);
                    // Get the updated value for the checkbox
                    const updatedValue = checked ? "1" : "0";
                    // Update permissions state based on checkbox change
                    const newValue = value.substring(0, index) + updatedValue + value.substring(index + 1);
                    console.log('click', newValue);
                    const newPermissions = Object.assign(Object.assign({}, permission), { [key]: newValue });
                    console.log('inside', checked);
                    setPermission(newPermissions);
                }}/>
              </div>
            </div>))}
        </div>
      </div>
    </div>
  </>))}

          </div>
          <Separator />
          <FuzMultiButton submitVariant="default" clearVariant="outline" submitlabel="Submit" clearlabel={isEdit === false ? "Clear" : undefined} submitType="submit" 
    // submitAction={handleSubmit}
    clearAction={() => {
            const currentType = form.getValues("type");
            console.log("currentType", currentType);
            setData(Object.assign(Object.assign({}, defaultValues), { type: currentType, name: '', description: '', permissionType: values.permissionType }));
            form.reset(Object.assign(Object.assign({}, defaultValues), { type: currentType, name: '', description: '', permissionType: values.permissionType }));
        }} loader={loader}/>
        </FormProvider>
      </Form>
    </div>);
}
