"use client";
import { __awaiter } from "tslib";
import { z } from "zod";
import { useEffect, useState, } from "react";
import { columns } from "./components/columns";
import { DataTable } from "./components/data-table";
import { roleSchema } from "./data/schema";
import { toast } from "../../../components/ui/use-toast";
import React from "react";
export default function RoleList({ supabase }) {
    const [listData, setListData] = useState([]);
    const [errorMessage, setErrorMessage] = useState(false);
    const [isLoading, setIsLoading] = useState(false);
    const [message, setMessage] = useState(null);
    const onCallStatus = (value) => {
        statusChange(value.id, value.status);
    };
    const onEdit = (value) => {
        console.log('done', value);
    };
    const onCallDelete = (value) => {
        console.log('done', value);
        removeUser(value.id);
    };
    const onRefresh = () => __awaiter(this, void 0, void 0, function* () {
        setIsLoading(true);
        try {
            const tenants = yield getTenants();
            setListData(tenants);
        }
        catch (error) {
            console.error("Error refreshing data:", error);
        }
        finally {
            setIsLoading(false);
        }
    });
    const [loader, setLoader] = useState(false);
    useEffect(() => {
        onRefresh(); // Call onRefresh when the component mounts
        setLoader(false);
    }, [loader]);
    const [dataLoader, setDataLoader] = useState(false);
    const getTenants = () => __awaiter(this, void 0, void 0, function* () {
        let { data, error } = yield supabase.auth.rolesList();
        console.log("hiii2");
        if (error) {
            console.error("Error fetching tenants:", error.message);
            setDataLoader(false);
            setErrorMessage(true);
            setMessage(error.message);
            return [];
        }
        else {
            setErrorMessage(false);
            setMessage(null);
            setDataLoader(true);
            return z.array(roleSchema).parse(data.role.roles);
        }
    });
    const statusChange = (id, status) => __awaiter(this, void 0, void 0, function* () {
        if (status === "Active") {
            status = "Inactive";
        }
        else {
            status = "Active";
        }
        let { error } = yield supabase.auth.changeRoleStatus({
            status: status,
            id: [id]
        });
        if (error) {
            console.error("Error fetching tenants:", error.message);
            toast({
                title: "You submitted the following values:",
                description: (<pre className="mt-2 w-[340px] rounded-md bg-slate-950 p-4">
            <code className="text-white">{error.message}</code>
          </pre>),
            });
        }
        else {
            toast({
                title: "You submitted the following values:",
                description: (<pre className="mt-2 w-[340px] rounded-md bg-slate-950 p-4">
            <code className="text-white">Successfully Updated</code>
          </pre>),
            });
            setLoader(true);
        }
    });
    const removeUser = (id) => __awaiter(this, void 0, void 0, function* () {
        let { error } = yield supabase.auth.deleteRole({
            id: id,
            tenant_id: ""
        });
        if (error) {
            console.error("Error fetching tenants:", error.message);
            toast({
                title: "You submitted the following values:",
                description: (<pre className="mt-2 w-[340px] rounded-md bg-slate-950 p-4">
            <code className="text-white">{error.message}</code>
          </pre>),
            });
        }
        else {
            toast({
                title: "You submitted the following values:",
                description: (<pre className="mt-2 w-[340px] rounded-md bg-slate-950 p-4">
            <code className="text-white">Successfully Deleted</code>
          </pre>),
            });
            setLoader(true);
        }
    });
    return (<>
      <DataTable columns={columns({ onEdit, onRefresh, onCallDelete, onCallStatus, supabase })} data={listData} supabase={supabase} errorMessage={errorMessage} isLoading={isLoading} onRefresh={onRefresh} message={message} dataLoader={dataLoader}/>
    </>);
}
