import { __awaiter } from "tslib";
import { useState, useEffect } from 'react';
import { zodResolver } from "@hookform/resolvers/zod";
import { useForm } from "react-hook-form";
import { z } from "zod";
import { Form } from "../../../../components/ui/form";
import { FormProvider, PhoneNumPicker, FuzSelect, FuzMultiButton, FuzTextField, } from "../../../../components/hook-form";
import { toast } from "../../../../components/ui/use-toast";
import React from 'react';
// Define schema using Zod based on the ven
// Define schema using Zod based on the vendors table structure
const emailRegex = /^[^\s@]+@[^\s@]+\.[^\s@]+$/;
const schema = z.object({
    name: z.string().min(1, "Name is required."),
    // other fields...
    subscription_details: z.object({
        plan_id: z.string(),
        plan_name: z.string(),
        plan_validity: z.string(),
    }).refine(value => {
        return Object.values(value).every(val => val !== '');
    }, { message: 'Subscription details are required' }),
    // status: z.string().min(1, 'required'),
    email: z.string()
        .min(1, { message: 'Email is required' })
        .refine(value => emailRegex.test(value), { message: 'Invalid email format' }),
    phone: z.string()
        .min(1, { message: 'Phone number is required' })
        .min(8, { message: 'Phone number must be at least 8 digits long' }),
});
// const schema = z.object({
//   plan_id: z.string(),
//   plan_name: z.string(),
//   plan_validity: z.string(),
//   email: z.string()
//     .min(1, { message: 'Email is required' })
//     .refine(value => emailRegex.test(value), { message: 'Invalid email format' }),
//   phone: z.string()
//     .min(1, { message: 'Phone number is required' })
//     .min(8, { message: 'Phone number must be at least 8 digits long' }),
// }).refine(value => {
//   const isEmpty = Object.values(value).every(val => typeof val !== 'string' || val !== '');
//   if (isEmpty) {
//     throw new Error('Subscription details are required');
//   }
//   return true;
// });
export default function VendorForm({ defaultValue, isEdit, onRefresh, setShowSideNav, supabase }) {
    var _a, _b;
    const [loader, setLoader] = useState(false);
    const [role_idData, setRole_idData] = useState([{
            plan_id: '1',
            plan_name: 'Standard',
            plan_validity: '2024-06-02'
        }, {
            plan_id: '2',
            plan_name: 'Enterprice',
            plan_validity: '2024-06-02'
        }]);
    const defaultValues = {
        id: (defaultValue === null || defaultValue === void 0 ? void 0 : defaultValue.id) || "",
        name: (defaultValue === null || defaultValue === void 0 ? void 0 : defaultValue.name) || "",
        email: (defaultValue === null || defaultValue === void 0 ? void 0 : defaultValue.email) || "",
        phone: (defaultValue === null || defaultValue === void 0 ? void 0 : defaultValue.phone) || "",
        country_code: '+91',
        plan_id: ((_a = defaultValue === null || defaultValue === void 0 ? void 0 : defaultValue.subscription_details) === null || _a === void 0 ? void 0 : _a.plan_id) || "",
        plan_name: ((_b = defaultValue === null || defaultValue === void 0 ? void 0 : defaultValue.subscription_details) === null || _b === void 0 ? void 0 : _b.plan_name) || "",
        subscription_details: (defaultValue === null || defaultValue === void 0 ? void 0 : defaultValue.subscription_details) || {
            plan_id: '',
            plan_name: '',
            plan_validity: ''
        },
        status: (defaultValue === null || defaultValue === void 0 ? void 0 : defaultValue.status) || "",
        default_user_id: (defaultValue === null || defaultValue === void 0 ? void 0 : defaultValue.default_user_id) || "00000000-0000-0000-0000-000000000000",
        default_user_name: (defaultValue === null || defaultValue === void 0 ? void 0 : defaultValue.default_user_name) || "",
        created_by: (defaultValue === null || defaultValue === void 0 ? void 0 : defaultValue.created_by) || "00000000-0000-0000-0000-000000000000",
        modified_by: (defaultValue === null || defaultValue === void 0 ? void 0 : defaultValue.modified_by) || "00000000-0000-0000-0000-000000000000",
        created_at: (defaultValue === null || defaultValue === void 0 ? void 0 : defaultValue.created_at) || new Date(),
        updated_at: (defaultValue === null || defaultValue === void 0 ? void 0 : defaultValue.updated_at) || new Date(),
    };
    console.log("defaultValues");
    const form = useForm({
        resolver: zodResolver(schema),
        defaultValues,
    });
    useEffect(() => {
        console.log(defaultValue, 'phonephonephonephone');
        function fetchDataFromTable(tableName, setStateCallback) {
            return __awaiter(this, void 0, void 0, function* () {
                try {
                    const { data, error } = yield supabase.from('tenant').select('*');
                    if (error) {
                        console.error(`Error fetching data from ${tableName}:`, error.message);
                    }
                    else {
                        setStateCallback(data || []);
                    }
                }
                catch (err) {
                    console.error(`Error fetching data from ${tableName}:`, err);
                }
            });
        }
        fetchDataFromTable('roles', setRole_idData);
    }, []);
    function onSubmit(_data) {
        return __awaiter(this, void 0, void 0, function* () {
            console.log("ff", _data);
            const obj = Object.assign(Object.assign({}, form.getValues()), { plan_id: _data.subscription_details.plan_id, plan_name: _data.subscription_details.plan_name, plan_validity: _data.subscription_details.plan_validity });
            try {
                if (isEdit) {
                    setLoader(true);
                    const { error } = yield supabase.auth.updateTenant(obj);
                    if (error) {
                        setTimeout(() => {
                            toast({
                                title: "Error",
                                variant: "destructive",
                                description: (<pre className="mt-2 w-[340px] rounded-md bg-slate-950 p-4">
                  <code className="text-white">{error.message}</code>
                </pre>),
                            });
                            setLoader(false);
                        }, 2000);
                    }
                    else {
                        setTimeout(() => {
                            setLoader(false);
                            form.reset();
                            toast({
                                title: "You submitted the following values:",
                                description: (<pre className="mt-2 w-[340px] rounded-md bg-slate-950 p-4">
                  <code className="text-white">Successfully Updated</code>
                </pre>),
                            });
                        }, 2000);
                        onRefresh();
                        setShowSideNav(false);
                    }
                }
                else {
                    setLoader(true);
                    console.log("Create Request Data :", form.getValues);
                    const obj = Object.assign(Object.assign({}, form.getValues()), { plan_id: _data.subscription_details.plan_id, plan_name: _data.subscription_details.plan_name, plan_validity: _data.subscription_details.plan_validity });
                    const { error } = yield supabase.auth.createTenant(obj);
                    if (error) {
                        setTimeout(() => {
                            toast({
                                title: "Error",
                                variant: "destructive",
                                description: (<pre className="mt-2 w-[340px] rounded-md bg-slate-950 p-4">
                  <code className="text-white">{error.message}</code>
                </pre>),
                            });
                            setLoader(false);
                        }, 2000);
                    }
                    else {
                        setTimeout(() => {
                            setLoader(false);
                            form.reset();
                            toast({
                                title: "You submitted the following values:",
                                description: (<pre className="mt-2 w-[340px] rounded-md bg-slate-950 p-4">
                  <code className="text-white">Successfully Created</code>
                </pre>),
                            });
                        }, 2000);
                        onRefresh();
                        setShowSideNav(false);
                    }
                }
            }
            catch (err) {
                console.error('Error fetching customers:', err);
            }
        });
    }
    // console.log("dataata",form.getValues())
    return (<div style={{ height: '80vh', overflowY: 'auto', }}> {/* Set height and overflow */}
      <div style={{ marginLeft: '4px', marginRight: '4px' }}>
        <Form {...form}>
          <FormProvider onSubmit={form.handleSubmit(onSubmit)} className="space-y-8">
            <div style={{ fontWeight: '700', fontSize: "20px" }}>
              {/* <h1>Tenant</h1> */}
            </div>
            <div style={{ display: 'grid', gridTemplateColumns: 'repeat(2, 1fr)', gap: '20px' }}>


              <FuzTextField label="Name" name="name" required type="character varying" placeholder="Name" form={form} maxLength={15}/>

              <FuzSelect label="Subscription Details" placeholder="Subscription Details" required name="subscription_details" options={role_idData} form={form} displayLabel="plan_name"/>
              {/* <FuzSelect
        label="status"
        placeholder="status"



        required
        name="status"
        options={status_idData}
        form={form}
      // displayLabel="plan_name"
      // returnLabel="id"
      /> */}
              <PhoneNumPicker required label="Phone Number" name="phone" form={form}/>
              {/* <FuzTextField
      label="country_code"
      name="country_code"
      type="character varying"

      placeholder="country_code"



      form={form}

    /> */}

            {!isEdit ? <FuzTextField label="Email" name="email" type="character varying" placeholder="Email" required form={form} pattern="Email"/> : ""}

              {/*  <FuzTextField
      label="password_hash"
      name="password_hash"
      type="password"

      placeholder="password_hash"



      form={form}
      pattern="Password"
    /> */}

            </div>
            <FuzMultiButton submitVariant="default" clearVariant="outline" submitlabel="Submit" clearlabel={isEdit === false ? "Clear" : undefined} submitType="submit" 
    // submitAction={handleSubmit}
    clearAction={() => form.reset(Object.assign(Object.assign({}, defaultValues), { phone: '' }))} loader={loader}/>
          </FormProvider>
        </Form>
      </div>
    </div>);
}
