import { __awaiter } from "tslib";
import * as React from "react";
import { Sheet, SheetContent, SheetHeader, SheetTitle, SheetDescription } from "../../../../components/ui/sheet";
import { z } from "zod";
import { tenantSchema } from "../data/schema";
import AddEditForm from "./AddEdit";
export default function SideNav({ showSideNav, onRefresh, data, onClose, isEdit = false, setShowSideNav, supabase }) {
    const [tenantDetail, setTenantDetails] = React.useState([]);
    // Fetch tenant details when component mounts
    function getTenants(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const { data, error } = yield supabase.auth.getTenantById({ id: id });
            if (error) {
                console.error("Error fetching tenant details:", error.message);
                return [];
            }
            // return []
            return z.array(tenantSchema).parse([data.role.Tenant]);
        });
    }
    React.useEffect(() => {
        if (showSideNav && (data === null || data === void 0 ? void 0 : data.id)) {
            (() => __awaiter(this, void 0, void 0, function* () {
                const details = yield getTenants(data.id);
                setTenantDetails(details);
            }))();
        }
    }, [showSideNav, data === null || data === void 0 ? void 0 : data.id]);
    React.useEffect(() => {
        console.log('tenantDetail', tenantDetail);
    }, [tenantDetail]);
    const handleClickOverlay = () => {
        onClose(); // Close the Sheet when clicking on overlay
    };
    return (<Sheet open={showSideNav} onOpenChange={handleClickOverlay}>
      <SheetContent className="w-[800px]" style={{
            maxWidth: '100%'
        }}>
        <SheetHeader className="px-2">
          <SheetTitle>TANENT</SheetTitle>
          <SheetDescription>
            {`${isEdit ? 'Update a tanent' : 'Create a tanent'}`}
          </SheetDescription>
          
        </SheetHeader>
        {isEdit && (tenantDetail === null || tenantDetail === void 0 ? void 0 : tenantDetail.length) > 0 ? <AddEditForm supabase={supabase} onRefresh={onRefresh} setShowSideNav={setShowSideNav} isEdit={isEdit} defaultValue={tenantDetail[0]}/> : !isEdit ? <AddEditForm setShowSideNav={setShowSideNav} onRefresh={onRefresh} isEdit={isEdit} defaultValue={undefined} supabase={supabase}/> : "Loading"}
      </SheetContent>
    </Sheet>);
}
