'use client';
import * as React from 'react';
import { flexRender, getCoreRowModel, getFacetedRowModel, getFacetedUniqueValues, getFilteredRowModel, getPaginationRowModel, getSortedRowModel, useReactTable, } from '@tanstack/react-table';
import { Table, TableBody, TableCell, TableHead, TableHeader, TableRow, } from '../../../../components/ui/table';
import { DataTablePagination } from './data-table-pagination';
import { DataTableToolbar } from './data-table-toolbar';
import { Skeleton } from '../../../../components/ui/skeleton';
export function DataTable({ columns, data, isLoading, onRefresh, errorMessage, message, supabase, dataLoader }) {
    var _a;
    const [rowSelection, setRowSelection] = React.useState({});
    const [columnVisibility, setColumnVisibility] = React.useState({});
    const [columnFilters, setColumnFilters] = React.useState([]);
    const [sorting, setSorting] = React.useState([]);
    const pageSizeArray = [10, 20, 30, 50, 100];
    const table = useReactTable({
        data,
        columns,
        state: {
            sorting,
            columnVisibility,
            rowSelection,
            columnFilters,
        },
        initialState: { pagination: { pageSize: 10 } },
        enableRowSelection: true,
        onRowSelectionChange: setRowSelection,
        onSortingChange: setSorting,
        onColumnFiltersChange: setColumnFilters,
        onColumnVisibilityChange: setColumnVisibility,
        getCoreRowModel: getCoreRowModel(),
        getFilteredRowModel: getFilteredRowModel(),
        getPaginationRowModel: getPaginationRowModel(),
        getSortedRowModel: getSortedRowModel(),
        getFacetedRowModel: getFacetedRowModel(),
        getFacetedUniqueValues: getFacetedUniqueValues(),
        autoResetPageIndex: true,
    });
    return (<div className="space-y-4">
      <DataTableToolbar table={table} onRefresh={onRefresh} supabase={supabase}/>
      <div className="rounded-md border">
        <Table>
          <TableHeader>
            {table.getHeaderGroups().map((headerGroup) => (<TableRow key={headerGroup.id}>
                {headerGroup.headers.map((header) => {
                return (<TableHead key={header.id} colSpan={header.colSpan}>
                      {header.isPlaceholder
                        ? null
                        : flexRender(header.column.columnDef.header, header.getContext())}
                    </TableHead>);
            })}
              </TableRow>))}
          </TableHeader>
          {errorMessage || dataLoader && data.length === 0 ? (<TableBody style={{ height: '100px' }}>
              <p style={{ textAlign: 'center', marginLeft: '350px', fontWeight: "bold" }} className="h-8 px-2 lg:px-3 ml-4 mt-4">
                {message ? message : "Data Not Found"}
              </p>
            </TableBody>) : (<TableBody>
              {isLoading ? (<>
                  {table.getHeaderGroups().map((headerGroup) => (<TableRow key={headerGroup.id}>
                      {headerGroup.headers.map((header) => {
                        return (<TableCell key={header.id} colSpan={header.colSpan} className="h-6">
                            <Skeleton className="w-[100px] h-[20px] rounded-full"/>
                          </TableCell>);
                    })}
                    </TableRow>))}
                  {table.getHeaderGroups().map((headerGroup) => (<TableRow key={headerGroup.id + '-2'}>
                      {headerGroup.headers.map((header) => {
                        return (<TableCell key={header.id + '-2'} colSpan={header.colSpan} className="h-6">
                            <Skeleton className="w-[100px] h-[20px] rounded-full"/>
                          </TableCell>);
                    })}
                    </TableRow>))}
                </>) : ((_a = table.getRowModel().rows) === null || _a === void 0 ? void 0 : _a.length) ? (table.getRowModel().rows.map((row) => (<TableRow key={row.id} data-state={row.getIsSelected() && 'selected'}>
                    {row.getVisibleCells().map((cell) => (<TableCell key={cell.id}>
                        {flexRender(cell.column.columnDef.cell, cell.getContext())}
                      </TableCell>))}
                  </TableRow>))) : (<TableRow>
                  <TableCell colSpan={columns.length} className="h-24 text-center">
                    <Skeleton className="w-[100px] h-[20px] rounded-full"/>
                  </TableCell>
                </TableRow>)}
            </TableBody>)}
        </Table>
      </div>
      <div className="flex items-center justify-between px-2">
        <div className="flex-1 text-sm text-muted-foreground">
          {table.getFilteredSelectedRowModel().rows.length} of{' '}
          {table.getFilteredRowModel().rows.length} row(s) selected.
        </div>
        <DataTablePagination table={table} pageSizeArray={errorMessage ? [0] : pageSizeArray}/>
      </div>
    </div>);
}
