"use client";
import { __awaiter } from "tslib";
import { z } from "zod";
import { useEffect, useState } from "react";
import { columns } from "./components/columns";
import { DataTable } from "./components/data-table";
import { tenantSchema } from "./data/schema";
import { toast } from "../../../components/ui/use-toast";
import React from "react";
export default function TenantList({ supabase }) {
    const [listData, setListData] = useState([]);
    const [isLoading, setIsLoading] = useState(false);
    const [errorMessage, setErrorMessage] = useState(false);
    const [message, setMessage] = useState(null);
    const onEdit = (value) => {
        console.log('done', value);
    };
    const oncallStatus = (value) => {
        validateTenants(value.id, value.status);
    };
    const onCallDelete = (value) => {
        var _a;
        console.log('done', value);
        removeUser((_a = value.id) !== null && _a !== void 0 ? _a : "");
    };
    const onRefresh = () => __awaiter(this, void 0, void 0, function* () {
        setIsLoading(true);
        try {
            const tenants = yield getTenants();
            setListData(tenants);
        }
        catch (error) {
            console.error("Error refreshing data:", error);
        }
        finally {
            setIsLoading(false);
        }
    });
    const [loader, setLoader] = useState(false);
    useEffect(() => {
        onRefresh(); // Call onRefresh when the component mounts
        setLoader(false);
    }, [loader]);
    const [dataLoader, setDataLoader] = useState(false);
    const getTenants = () => __awaiter(this, void 0, void 0, function* () {
        let { data, error } = yield supabase.auth.tenantsList();
        console.log(data, 'datadatadata');
        if (error) {
            console.error("Error fetching tenants:", error.message);
            setDataLoader(false);
            setErrorMessage(true);
            setMessage(error.message);
            return [];
        }
        else {
            setErrorMessage(false);
            setMessage(null);
            setDataLoader(true);
            return z.array(tenantSchema).parse(data.tenant.tenants);
        }
    });
    const removeUser = (id) => __awaiter(this, void 0, void 0, function* () {
        let { data, error } = yield supabase.auth.deleteTenant({
            id: id,
        });
        if (error) {
            console.error("Error fetching tenants:", error.message);
            toast({
                title: "You submitted the following values:",
                description: (<pre className="mt-2 w-[340px] rounded-md bg-slate-950 p-4">
            <code className="text-white">{error.message}</code>
          </pre>),
            });
        }
        else {
            onRefresh();
            toast({
                title: "You submitted the following values:",
                description: (<pre className="mt-2 w-[340px] rounded-md bg-slate-950 p-4">
            <code className="text-white">{data.message}</code>
          </pre>),
            });
        }
    });
    const validateTenants = (id, status) => __awaiter(this, void 0, void 0, function* () {
        if (status === "Active") {
            status = "Inactive";
        }
        else {
            status = "Active";
        }
        let { data, error } = yield supabase.auth.changeRoleStatus({ status: status, id: [id] });
        console.log(data, 'datadatadata');
        if (error) {
            console.error("Error fetching tenants:", error.message);
            toast({
                title: "You submitted the following values:",
                description: (<pre className="mt-2 w-[340px] rounded-md bg-slate-950 p-4">
            <code className="text-white">{error.message}</code>
          </pre>),
            });
        }
        else {
            toast({
                title: "You submitted the following values:",
                description: (<pre className="mt-2 w-[340px] rounded-md bg-slate-950 p-4">
            <code className="text-white">Successfully Updated</code>
          </pre>),
            });
            setLoader(true);
        }
    });
    return (<>

      <DataTable columns={columns({ onEdit, onRefresh, onCallDelete, oncallStatus, supabase })} data={listData} supabase={supabase} isLoading={isLoading} errorMessage={errorMessage} onRefresh={onRefresh} message={message} dataLoader={dataLoader}/>
    </>);
}
