import { __awaiter, __rest } from "tslib";
import { useState, useEffect } from 'react';
import { zodResolver } from "@hookform/resolvers/zod";
import { useForm } from "react-hook-form";
import { z } from "zod";
import { Form } from "../../../../components/ui/form";
import { FormProvider, FuzSelect, FuzMultiButton, FuzTextField } from "../../../../components/hook-form";
import { toast } from "../../../../components/ui/use-toast";
import React from 'react';
// Define schema using Zod based on the ven
// Define schema using Zod based on the vendors table structure
const emailRegex = /^[^\s@]+@[^\s@]+\.[^\s@]+$/;
const schema = z.object({
    name: z.string().min(1, 'Name is required'),
    email: z.string()
        .min(1, { message: 'Email is required' })
        .refine(value => emailRegex.test(value), { message: 'Invalid email format' }),
    password: z.string().min(0, 'Password is required').min(6, 'Password must be at least 6 characters long'),
    role_id: z.string().min(1, 'Role ID is required'),
    phone: z.string().min(1, 'Phone number is required').min(10, 'Invalid phone number'),
    // user_metadata: 
});
const schemaEdit = z.object({
    name: z.string().min(1, 'Name is required'),
    email: z.string()
        .min(1, { message: 'Email is required' })
        .refine(value => emailRegex.test(value), { message: 'Invalid email format' }),
    role_id: z.string().min(1, 'Role ID is required'),
    phone: z.string().min(1, 'Phone number is required').min(10, 'Invalid phone number'),
    // user_metadata: 
});
export default function VendorForm({ defaultValue, isEdit, onReferesh, setShowSideNav, supabaseAuthAdmin }) {
    const [loader, setLoader] = useState(false);
    const [role_idData, setRole_idData] = useState([]);
    const defaultValues = {
        id: (defaultValue === null || defaultValue === void 0 ? void 0 : defaultValue.id) || "",
        email: (defaultValue === null || defaultValue === void 0 ? void 0 : defaultValue.email) || "",
        password: (defaultValue === null || defaultValue === void 0 ? void 0 : defaultValue.password) || "",
        phone: (defaultValue === null || defaultValue === void 0 ? void 0 : defaultValue.phone) || "",
        role_id: (defaultValue === null || defaultValue === void 0 ? void 0 : defaultValue.role_id) || "",
        name: (defaultValue === null || defaultValue === void 0 ? void 0 : defaultValue.user_metadata.name) || "",
    };
    const form = useForm({
        resolver: isEdit ? zodResolver(schemaEdit) : zodResolver(schema),
        defaultValues,
    });
    console.log("defaultValues", defaultValues);
    useEffect(() => {
        function fetchDataFromTable(tableName, setStateCallback) {
            return __awaiter(this, void 0, void 0, function* () {
                try {
                    const { data, error } = yield supabaseAuthAdmin.auth.rolesList();
                    if (error) {
                        console.error(`Error fetching data from ${tableName}:`, error.message);
                        setStateCallback([]);
                    }
                    else {
                        setStateCallback(data.role.roles);
                    }
                }
                catch (err) {
                    console.error(`Error fetching data from ${tableName}:`, err);
                }
            });
        }
        fetchDataFromTable('roles', setRole_idData);
    }, []);
    function onSubmit(_data) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                if (isEdit) {
                    setLoader(true);
                    // const { data: insertedData, error } = await supabase.auth.createTenant(form.getValues())
                    const values = form.getValues();
                    const { password, name } = values, rest = __rest(values, ["password", "name"]);
                    const obj = Object.assign(Object.assign({}, rest), { user_metadata: {
                            name: values.name
                        } });
                    let { error } = yield supabaseAuthAdmin.auth.admin.updateUserById(obj.id, obj);
                    if (error) {
                        setTimeout(() => {
                            toast({
                                title: "Error",
                                variant: "destructive",
                                description: (<pre className="mt-2 w-[340px] rounded-md bg-slate-950 p-4">
                  <code className="text-white">Something Went Wrong</code>
                </pre>),
                            });
                            setLoader(false);
                        }, 2000);
                    }
                    else {
                        onReferesh();
                        setShowSideNav(false);
                        setTimeout(() => {
                            setLoader(false);
                            form.reset();
                            toast({
                                title: "You submitted the following values:",
                                description: (<pre className="mt-2 w-[340px] rounded-md bg-slate-950 p-4">
                  <code className="text-white">Successfully Updated</code>
                </pre>),
                            });
                        }, 2000);
                    }
                }
                else {
                    setLoader(true);
                    // const { data: insertedData, error } = await supabase.auth.updateTenant(form.getValues)
                    const values = form.getValues();
                    const { name } = values, rest = __rest(values, ["name"]);
                    const obj = Object.assign(Object.assign({}, rest), { user_metadata: {
                            name: values.name
                        } });
                    let { error } = yield supabaseAuthAdmin.auth.admin.createUser(obj);
                    if (error) {
                        setTimeout(() => {
                            toast({
                                title: "Error",
                                variant: "destructive",
                                description: (<pre className="mt-2 w-[340px] rounded-md bg-slate-950 p-4">
                  <code className="text-white">Something Went Wrong</code>
                </pre>),
                            });
                            setLoader(false);
                        }, 2000);
                    }
                    else {
                        setTimeout(() => {
                            onReferesh();
                            setLoader(false);
                            setShowSideNav(false);
                            form.reset();
                            toast({
                                title: "You submitted the following values:",
                                description: (<pre className="mt-2 w-[340px] rounded-md bg-slate-950 p-4">
                  <code className="text-white">Successfully Created</code>
                </pre>),
                            });
                        }, 2000);
                    }
                }
            }
            catch (err) {
                console.error('Error fetching customers:', err);
            }
        });
    }
    useEffect(() => {
        if (role_idData && role_idData.length > 0) {
            console.log(role_idData, 'role_idData');
        }
    }, [role_idData]);
    // console.log("dataata",form.getValues())
    return (<Form {...form}>
      <FormProvider onSubmit={form.handleSubmit(onSubmit)} className="space-y-8">
        <div style={{ fontWeight: '700', fontSize: "20px" }}>
          {/* <h1>User</h1> */}
        </div>
        <div style={{ display: 'grid', gridTemplateColumns: 'repeat(2, 1fr)', gap: '20px' }}>
          
        <FuzTextField label="Name" name="name" type="text" placeholder="Name" form={form} required maxLength={15}/>

          <FuzTextField label="Email" name="email" type="character varying" placeholder="Email" form={form} required maxLength={25}/>
          <FuzTextField label="Phone Number" name="phone" type="character varying" placeholder="Phone Number" form={form} required maxLength={10}/>
          {!isEdit ? <FuzTextField label="Password" name="password" type="password" required placeholder="Password" maxLength={10} form={form} pattern="Password"/> : ""}

  
              <FuzSelect label="Role" placeholder="Select Role" required name="role_id" options={role_idData} form={form} displayLabel="name" returnLabel="id"/> 
               {/* <FuzSelect
         label="Role Type"
         placeholder="Role Type"
         required
         name="role_id"
         options={role_idData}
         form={form}
         displayLabel="name"
         returnLabel="id"
       /> */}


          {/* <PhoneNumPicker

          required
          label="mobile_number"
          name="mobile_number"
          form={form}
        />
        <FuzTextField
          label="country_code"
          name="country_code"
          type="character varying"

          placeholder="country_code"



          form={form}

        />

        <FuzTextField
          label="email"
          name="email"
          type="character varying"

          placeholder="email"


          required
          form={form}
          pattern="Email"
        />

        <FuzTextField
          label="password_hash"
          name="password_hash"
          type="password"

          placeholder="password_hash"



          form={form}
          pattern="Password"
        /> */}

        </div>
        <FuzMultiButton submitVariant="default" clearVariant="outline" submitlabel="Submit" clearlabel={isEdit === false ? "Clear" : undefined} submitType="submit" 
    // submitAction={handleSubmit}
    clearAction={() => {
            console.log("form", form);
            form.reset(Object.assign(Object.assign({}, defaultValues), { email: '', phone: '' }));
        }} loader={loader}/>
      </FormProvider>
    </Form>);
}
