import { __awaiter } from "tslib";
import * as React from "react";
import { Sheet, SheetContent, SheetHeader, SheetTitle, SheetDescription } from "../../../../components/ui/sheet";
import { z } from "zod";
import { userSchema } from "../data/schema";
import AddEditForm from "./AddEdit";
export default function SideNav({ showSideNav, onRefresh, data, onClose, isEdit = false, setShowSideNav, supabaseAuthAdmin }) {
    const [tenantDetail, setTenantDetails] = React.useState([]);
    // Fetch tenant details when component mounts
    function getTenants(id) {
        return __awaiter(this, void 0, void 0, function* () {
            let { data: { user }, error } = yield supabaseAuthAdmin.auth.admin.getUserById(id);
            if (error) {
                console.error("Error fetching tenant details:", error.message);
                return [];
            }
            // return []
            return z.array(userSchema).parse([user]);
        });
    }
    React.useEffect(() => {
        if (showSideNav && (data === null || data === void 0 ? void 0 : data.id)) {
            (() => __awaiter(this, void 0, void 0, function* () {
                const details = yield getTenants(data.id);
                setTenantDetails(details);
            }))();
        }
    }, [showSideNav, data === null || data === void 0 ? void 0 : data.id]);
    React.useEffect(() => {
        console.log('tenantDetail', tenantDetail);
    }, [tenantDetail]);
    const handleClickOverlay = () => {
        onClose(); // Close the Sheet when clicking on overlay
    };
    return (<Sheet open={showSideNav} onOpenChange={handleClickOverlay}>
      <SheetContent className="w-[800px]" style={{
            maxWidth: '100%'
        }}>
        <SheetHeader>
          <SheetTitle>USER</SheetTitle>
          <SheetDescription>
          {`${isEdit ? 'Update a user' : 'Create a new user'} `}
            {isEdit && (tenantDetail === null || tenantDetail === void 0 ? void 0 : tenantDetail.length) > 0 ? <AddEditForm supabaseAuthAdmin={supabaseAuthAdmin} onReferesh={onRefresh} setShowSideNav={setShowSideNav} isEdit={isEdit} defaultValue={tenantDetail[0]}/> : !isEdit ? <AddEditForm supabaseAuthAdmin={supabaseAuthAdmin} onReferesh={onRefresh} setShowSideNav={setShowSideNav} isEdit={isEdit} defaultValue={undefined}/> : "Loading"}
          </SheetDescription>
        </SheetHeader>
      </SheetContent>
    </Sheet>);
}
