"use client";
import { __awaiter } from "tslib";
import { z } from "zod";
import { useEffect, useState } from "react";
import { columns } from "./components/columns";
import { DataTable } from "./components/data-table";
import { userSchema } from "./data/schema";
import { toast } from "../../../components/ui/use-toast";
import React from "react";
export default function UserList({ supabase, supabaseAuthAdmin }) {
    const [listData, setListData] = useState([]);
    const [isLoading, setIsLoading] = useState(false);
    const [errorMessage, setErrorMessage] = useState(false);
    const [message, setMessage] = useState(null);
    const onEdit = (value) => {
        console.log('done', value);
    };
    const onRefresh = () => __awaiter(this, void 0, void 0, function* () {
        setIsLoading(true);
        try {
            const tenants = yield getTenants();
            setListData(tenants);
        }
        catch (error) {
            console.error("Error refreshing data:", error);
        }
        finally {
            setIsLoading(false);
        }
    });
    const [loader, setLoader] = useState(false);
    useEffect(() => {
        onRefresh(); // Call onRefresh when the component mounts
        setLoader(false);
    }, [loader]);
    const [dataLoader, setDataLoader] = useState(false);
    const getTenants = () => __awaiter(this, void 0, void 0, function* () {
        let { data: { users }, error } = yield supabaseAuthAdmin.auth.admin.listUsers();
        console.log('tenants', users);
        if (error) {
            console.error("Error fetching tenants:", error.message);
            setErrorMessage(true);
            setMessage(error.message);
            setDataLoader(false);
            return [];
        }
        else {
            setErrorMessage(false);
            setMessage(null);
            setDataLoader(true);
            return z.array(userSchema).parse(users);
            // return []
        }
    });
    const onCallDelete = (value) => {
        console.log('done', value);
        removeUser(value.id);
    };
    const removeUser = (id) => __awaiter(this, void 0, void 0, function* () {
        let { error } = yield supabase.auth.admin.deleteUser(id);
        if (error) {
            console.error("Error fetching tenants:", error.message);
            toast({
                title: "You submitted the following values:",
                description: (<pre className="mt-2 w-[340px] rounded-md bg-slate-950 p-4">
            <code className="text-white">{error.message}</code>
          </pre>),
            });
        }
        else {
            onRefresh();
            toast({
                title: "You submitted the following values:",
                description: (<pre className="mt-2 w-[340px] rounded-md bg-slate-950 p-4">
            <code className="text-white">Successfully Deleted</code>
          </pre>),
            });
            setLoader(true);
        }
    });
    const oncallStatus = (value) => {
        validateTenants(value.id, value.status);
    };
    const validateTenants = (id, status) => __awaiter(this, void 0, void 0, function* () {
        if (status === "Active") {
            status = "Inactive";
        }
        else {
            status = "Active";
        }
        let { data, error } = yield supabase.auth.admin.changeUserStatus({ status: status, id: [id] });
        console.log(data, 'datadatadata');
        if (error) {
            console.error("Error fetching tenants:", error.message);
            toast({
                title: "You submitted the following values:",
                description: (<pre className="mt-2 w-[340px] rounded-md bg-slate-950 p-4">
            <code className="text-white">{error.message}</code>
          </pre>),
            });
        }
        else {
            onRefresh();
            toast({
                title: "You submitted the following values:",
                description: (<pre className="mt-2 w-[340px] rounded-md bg-slate-950 p-4">
            <code className="text-white">{data.message}</code>
          </pre>),
            });
        }
    });
    return (<>
        <DataTable columns={columns({ onEdit, onRefresh, onCallDelete, oncallStatus, supabaseAuthAdmin })} data={listData} supabaseAuthAdmin={supabaseAuthAdmin} isLoading={isLoading} onRefresh={onRefresh} errorMessage={errorMessage} message={message} dataLoader={dataLoader}/>
      
    </>);
}
