import React from 'react';
import { FormControl, FormField, FormItem, FormLabel, FormDescription } from '../../components/ui/form';
import { Checkbox } from '../../components/ui/checkbox';
const ShadowedCheckbox = ({ placeholder, required, info, options, label, name, form }) => {
    const { formState: { errors }, getValues, setValue } = form;
    // Convert string array to Option array if needed
    const normalizedOptions = (Array.isArray(options) && options.length > 0 && typeof options[0] === 'string')
        ? options.map(option => ({ id: option, label: option }))
        : options;
    return (<FormField control={form.control} name={name} render={({ field }) => (<FormItem>
          <FormControl>
            {options ? (<div>
                <div className="mb-4">
                  <FormLabel className="text-base">{label}</FormLabel>
                  <FormDescription>
            {placeholder}                  </FormDescription>
                </div>
                {normalizedOptions === null || normalizedOptions === void 0 ? void 0 : normalizedOptions.map((option) => (<FormItem key={option.id} className="flex items-center space-x-2">
                    <Checkbox name={`${name}[${option.id}]`} checked={Array.isArray(getValues(name)) && getValues(name).includes(option.id)} onCheckedChange={(checked) => {
                        const currentValues = getValues(name) || [];
                        const newItems = checked
                            ? [...currentValues, option.id]
                            : currentValues.filter((value) => value !== option.id);
                        setValue(name, newItems);
                    }}/>
                    <FormLabel>{option.label}</FormLabel>
                  </FormItem>))}
              </div>) : (<div className="flex items-center space-x-2">
                <Checkbox name={name} checked={!!field.value} onCheckedChange={field.onChange}/>
                <FormLabel info={info} required={required}>{label}</FormLabel>
              </div>)}
          </FormControl>
          {errors[name] && (<span className="text-red-500">{errors[name].message}</span>)}
        </FormItem>)}/>);
};
export default ShadowedCheckbox;
