// ShadowedRadioGroup.tsx
import React from 'react';
import { useFormContext } from 'react-hook-form';
import { FormField, FormItem, FormLabel, FormMessage } from "../../components/ui/form";
import { RadioGroup, RadioGroupItem } from "../../components/ui/radio-group";
const ShadowedRadioGroup = ({ info, required, options, label, name, form }) => {
    const { setValue } = useFormContext();
    // Normalize options to always be an array of Option objects
    const normalizedOptions = (options || []).map((option) => {
        if (typeof option === 'string') {
            // If it's a string, use it for both label and value
            return { label: option, value: option };
        }
        // If it's already an Option object, just return it
        return option;
    });
    // Set the default selected value based on `field.value`
    React.useEffect(() => {
        setValue(name, form.watch(name));
    }, [setValue, name, form]);
    return (<FormField control={form.control} name={name} render={({ field }) => (<FormItem className="space-y-3">
          <FormLabel info={info} required={required}>{label}</FormLabel>
          <RadioGroup onValueChange={field.onChange} value={field.value} className="flex flex-col space-y-1">
            {normalizedOptions === null || normalizedOptions === void 0 ? void 0 : normalizedOptions.map(option => (<FormItem key={option.value} className="flex items-center space-x-3 space-y-0">
                <RadioGroupItem value={option.value}/>
                <FormLabel className="font-normal">{option.label}</FormLabel>
              </FormItem>))}
          </RadioGroup>
          <FormMessage />
        </FormItem>)}/>);
};
export default ShadowedRadioGroup;
