"use client";
import Link from "next/link";
import { usePathname } from "next/navigation";
import Image from 'next/image';
import { cn } from "../../../lib/utils";
import { buttonVariants } from "../../../components/ui/button";
import { Tooltip, TooltipContent, TooltipTrigger, } from "../../../components/ui/tooltip";
import React from "react";
export function Nav({ links, isCollapsed, setIsCollapsed }) {
    const pathname = usePathname();
    function getDomainFromUrl(url, hrefLink) {
        console.log(url, hrefLink);
        try {
            const urlObject = new URL(url);
            const hostname = urlObject.hostname;
            const port = urlObject.port;
            return `http://${hostname}:${port}${hrefLink}`;
        }
        catch (error) {
            console.error('Invalid URL:', error.message);
            return '';
        }
    }
    return (<nav className={`fixed hide-scrollbar bg-white z-20 border-r left-0 h-full gap-3 py-2 px-2 group-[[data-collapsed=true]]:px-2 overflow-y-auto flex flex-col ${isCollapsed ? 'w-14' : 'w-64'} `} onMouseEnter={() => setIsCollapsed(false)} onMouseLeave={() => setIsCollapsed(true)}>
      <Link href="https://fuzionest.com/" // replace with your website URL
     className={cn("py-2")}>
        <Image src="/images/logo.png" // replace with the path to your logo
     alt="Logo" width={32} height={32}/>

      </Link>

      {links.map((link, index) => {
            var _a, _b;
            return isCollapsed ? (<Tooltip key={index} delayDuration={0}>
            <TooltipTrigger asChild>
              <Link href={link.hrefLink} className={cn(buttonVariants({
                    variant: 'ghost',
                    size: "icon"
                }), "text-gray", "h-9 w-9", "py-2", pathname === link.hrefLink ? "bg-muted hover:bg-muted" :
                    "hover:bg-transparent hover:underline")}>
                <link.icon className="h-4 w-4"/>
                <span className="sr-only">{link.title}</span>
              </Link>
            </TooltipTrigger>
            <TooltipContent side="right" className="flex items-center gap-4">
              {link.title}
              {/* {link.label && (
                  <span className="ml-auto text-muted-foreground">
                    {link.label}
                  </span>
                )} */}
            </TooltipContent>
          </Tooltip>) : (<Link key={index} href={link.hrefLink} className={cn(buttonVariants({ variant: (typeof window !== 'undefined' && ((_a = window === null || window === void 0 ? void 0 : window.location) === null || _a === void 0 ? void 0 : _a.href) === getDomainFromUrl((_b = window === null || window === void 0 ? void 0 : window.location) === null || _b === void 0 ? void 0 : _b.href, link.hrefLink)) ? link.variant : 'ghost', size: "sm" }), link.variant === "secondary" &&
                    "dark:bg-muted dark:text-white dark:hover:bg-muted dark:hover:text-white", "justify-start")}>
            <link.icon className="mr-2 h-4 w-4"/>
            {link.title}
            {/* {link.label && (
                  <span
                    className={cn(
                      "ml-auto",
                      typeof window !== 'undefined' && window?.location?.href === getDomainFromUrl(window?.location?.href, link.hrefLink) &&
                      "text-background dark:text-white"
                    )}
                  >
                    {link.label}
                  </span>
                )} */}
          </Link>);
        })}
    </nav>);
}
