import React, { forwardRef, useEffect } from "react";
import { DatePicker } from "antd";
import { useFormContext } from "react-hook-form";
import dayjs from "dayjs";
import moment from "moment";
const DateWithTime = forwardRef(({ dateFieldName, defaultValue, minDate, maxDate, minTime, maxTime }) => {
    const { setValue } = useFormContext();
    useEffect(() => {
        setValue(dateFieldName, defaultValue[dateFieldName]);
    }, [defaultValue, setValue, dateFieldName]);
    const handleDateWithChange = (_date, dateString) => {
        const formattedDateString = Array.isArray(dateString) ? dateString.join(', ') : dateString;
        setValue(dateFieldName, formattedDateString);
    };
    const defaultOpenValue = defaultValue && dateFieldName
        ? dayjs(moment(defaultValue[dateFieldName], 'YYYY-MM-DD HH:mm:ss').toDate())
        : dayjs(); // This will set the current date and time
    const minimumTime = moment(minTime, 'h:mm A');
    const maximumTime = moment(maxTime, 'h:mm A');
    const disabledHours = () => {
        const hours = []; // Explicitly type the array as number[]
        const minHour = Number(minimumTime.hour());
        const maxHour = Number(maximumTime.hour());
        for (let i = 0; i < 24; i++) {
            if (i < minHour || i > maxHour) {
                hours.push(i);
            }
        }
        return hours;
    };
    const disabledMinutes = (selectedHour) => {
        if (selectedHour === minimumTime.hour()) {
            const minutes = []; // Explicitly type the array as number[]
            for (let i = 0; i < 60; i++) {
                if (i < minimumTime.minute()) {
                    minutes.push(i);
                }
            }
            return minutes;
        }
        else if (selectedHour === maximumTime.hour()) {
            const minutes = []; // Explicitly type the array as number[]
            for (let i = 0; i < 60; i++) {
                if (i > maximumTime.minute()) {
                    minutes.push(i);
                }
            }
            return minutes;
        }
        return [];
    };
    const disabledSeconds = (selectedHour, selectedMinute) => {
        const seconds = []; // Explicitly type the array as number[]
        const minSecond = Number(minimumTime.second());
        const maxSecond = Number(maximumTime.second());
        if (selectedHour === minimumTime.hour() && selectedMinute === minimumTime.minute()) {
            for (let i = 0; i < 60; i++) {
                if (i < minSecond) {
                    seconds.push(i);
                }
            }
        }
        else if (selectedHour === maximumTime.hour() && selectedMinute === maximumTime.minute()) {
            for (let i = 0; i < 60; i++) {
                if (i > maxSecond) {
                    seconds.push(i);
                }
            }
        }
        return seconds;
    };
    return (<DatePicker showTime onChange={handleDateWithChange} defaultValue={defaultOpenValue} allowClear={false} disabledDate={(current) => !!current && ((!!minDate && current.isBefore(dayjs(minDate), "day")) ||
            (!!maxDate && current.isAfter(dayjs(maxDate), "day")))} disabledHours={disabledHours} disabledMinutes={disabledMinutes} disabledSeconds={disabledSeconds}/>);
});
DateWithTime.displayName = "DateWithTime";
export default DateWithTime;
