import React, { useState } from 'react';
import { useFormContext } from 'react-hook-form';
import { Stack, DateRangePicker } from 'rsuite';
import moment from 'moment'; // Import moment library for date handling
import 'rsuite/dist/rsuite.css';
import { isBefore, isAfter } from 'date-fns';
import { TimePicker } from 'antd';
import dayjs from 'dayjs'; // Import dayjs library
import DateWithTime from './dateWithTime';
import TimeRange from './timeRange';
import { DatePicker, } from 'rsuite';
const Datepicker = (props) => {
    const { dateFieldName, picker, defaultValue, maxDate, minDate, minTime, maxTime } = props;
    const { setValue, } = useFormContext();
    console.log("defaultValue", defaultValue);
    const selectedDefaultValue = defaultValue;
    const DateRangeStart = defaultValue;
    const startDate = DateRangeStart ? moment(DateRangeStart.startDate).toDate() : new Date();
    const endDate = DateRangeStart ? moment(DateRangeStart.endDate).toDate() : new Date();
    const [selectedDate] = useState(selectedDefaultValue ? moment(selectedDefaultValue).toDate() : new Date());
    const handleDateChange = (date) => {
        const formattedDate = date ? moment(date).format('YYYY-MM-DD') : '';
        setValue(dateFieldName, formattedDate);
    };
    const handleTimeChange = (date, dateString) => {
        if (date && typeof dateString === 'string') {
            const indianTime = date.format('HH:mm:ss');
            setValue(dateFieldName, indianTime);
        }
    };
    const handleDateRangeChange = (dateRange) => {
        const startDate = dateRange ? moment(dateRange[0]).format('YYYY-MM-DD') : '';
        const endDate = dateRange ? moment(dateRange[1]).format('YYYY-MM-DD') : '';
        setValue(dateFieldName, { startDate, endDate });
    };
    const minimumDate = new Date(minDate);
    const maximumDate = new Date(maxDate);
    const minimumTime = moment(minTime, 'h:mm A');
    const maximumTime = moment(maxTime, 'h:mm A');
    const disabledHours = () => {
        const hours = []; // Explicitly type the array as number[]
        const minHour = Number(minimumTime.hour());
        const maxHour = Number(maximumTime.hour());
        for (let i = 0; i < 24; i++) {
            if (i < minHour || i > maxHour) {
                hours.push(i);
            }
        }
        return hours;
    };
    const disabledMinutes = (selectedHour) => {
        if (selectedHour === minimumTime.hour()) {
            const minutes = []; // Explicitly type the array as number[]
            for (let i = 0; i < 60; i++) {
                if (i < minimumTime.minute()) {
                    minutes.push(i);
                }
            }
            return minutes;
        }
        else if (selectedHour === maximumTime.hour()) {
            const minutes = []; // Explicitly type the array as number[]
            for (let i = 0; i < 60; i++) {
                if (i > maximumTime.minute()) {
                    minutes.push(i);
                }
            }
            return minutes;
        }
        return [];
    };
    const disabledSeconds = (selectedHour, selectedMinute) => {
        const seconds = []; // Explicitly type the array as number[]
        if (selectedHour === minimumTime.hour() && selectedMinute === minimumTime.minute()) {
            for (let i = 0; i < 60; i++) {
                if (i < minimumTime.second()) {
                    seconds.push(i);
                }
            }
            return seconds;
        }
        else if (selectedHour === maximumTime.hour() && selectedMinute === maximumTime.minute()) {
            for (let i = 0; i < 60; i++) {
                if (i > maximumTime.second()) {
                    seconds.push(i);
                }
            }
            return seconds;
        }
        return [];
    };
    const maxTimeParts = maxTime ? maxTime.split(/[.: ]/) : "";
    var hours = parseInt(maxTimeParts[0]);
    var maxTimeminutes = parseInt(maxTimeParts[1]);
    if (maxTimeParts[2] === "PM" && hours !== 12) {
        hours += 12;
    }
    console.log("Minutes1:", maxTimeminutes);
    const minTimeParts = minTime ? minTime.split(/[.: ]/) : "";
    var hours = parseInt(minTimeParts[0]);
    var minTimeminutes = parseInt(minTimeParts[1]);
    if (minTimeParts[2] === "PM" && hours !== 12) {
        hours += 12;
    }
    console.log("Minutes2:", minTimeminutes);
    const defaultOpenValue = dayjs(moment(defaultValue, 'HH:mm:ss').toDate());
    return (<React.Fragment>
      <Stack direction="column" style={{ display: 'block' }}>
        {(() => {
            switch (picker) {
                case 'date':
                    return (<DatePicker style={{ width: "100%" }} shouldDisableDate={date => isBefore(date, minimumDate) || isAfter(date, maximumDate)} defaultValue={selectedDate} onChange={handleDateChange} format="yyyy-MM-dd"/>);
                case 'dateRange':
                    return <DateRangePicker style={{ width: "100%" }} onChange={handleDateRangeChange} defaultValue={[startDate, endDate]} shouldDisableDate={date => isBefore(date, minimumDate) || isAfter(date, maximumDate)}/>;
                case 'timeRange':
                    return (<TimeRange minTime={minTime} maxTime={maxTime} dateFieldName={dateFieldName} defaultValue={defaultValue}/>);
                case 'dateWithTime':
                    return (<DateWithTime minTime={minTime} maxTime={maxTime} maxDate={maxDate} minDate={minDate} dateFieldName={dateFieldName} defaultValue={defaultValue}/>);
                default:
                    return (<TimePicker onChange={handleTimeChange} defaultValue={defaultOpenValue} disabledHours={disabledHours} disabledMinutes={disabledMinutes} disabledSeconds={disabledSeconds}/>);
            }
        })()}
      </Stack>
    </React.Fragment>);
};
export { Datepicker };
