import { __rest } from "tslib";
import React, { useState } from "react";
import { cn } from "../../lib/utils";
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { faEye, faEyeSlash } from '@fortawesome/free-solid-svg-icons';
const Input = React.forwardRef((_a, ref) => {
    var { className, type = "text", pattern, minLength, maxLength, info } = _a, props = __rest(_a, ["className", "type", "pattern", "minLength", "maxLength", "info"]);
    const [showPassword, setShowPassword] = useState(false); // State to toggle password visibility
    const handleInputChange = (e) => {
        const inputValue = e.target.value;
        let filteredValue = inputValue;
        switch (pattern) {
            case 'Text':
                filteredValue = inputValue.replace(/^\s+|[^A-Za-z]+/g, ''); // Allow alphabetical letters and space
                break;
            case 'Email':
                filteredValue = inputValue.replace(/[^A-Za-z0-9@._-]/g, '').toLowerCase(); // Allow email characters
                break;
            case 'Number':
                filteredValue = inputValue.replace(/[^\d]/g, ''); // Allow only number
                break;
            case 'GST':
                filteredValue = inputValue.replace(/[^A-Za-z0-9]/g, '').toUpperCase(); // Allow only letters and numbers
                break;
            case 'URL':
                filteredValue = inputValue.replace(/[^A-Za-z0-9!@#$%^&*_+\-=;:'",./?]/g, '');
                break;
            case 'Decimal': {
                filteredValue = inputValue.replace(/[^\d.]/g, '');
                const parts = filteredValue.split('.');
                if (parts.length > 2) {
                    // More than one dot found, remove extra dots
                    const integerPart = parts.shift(); // Remove the first part (before the first dot)
                    const decimalPart = parts.join(''); // Join remaining parts together (after the first dot)
                    filteredValue = integerPart + '.' + decimalPart; // Concatenante them back with a dot
                }
                else {
                    parts[0] = parts[0].slice(0, 9);
                    if (parts[1]) {
                        parts[1] = parts[1].slice(0, 2);
                    }
                    filteredValue = parts.join('.');
                }
                break;
            }
            case 'Text With Space':
                filteredValue = inputValue.replace(/^\s+|[^A-Za-z\s]+/g, ''); // Allow alphabetical letters and space
                break;
            case 'Text Number':
                filteredValue = inputValue.replace(/[^A-Za-z0-9]/g, ''); // Allow only letters and numbers
                break;
            case 'Upper Case':
                filteredValue = inputValue.replace(/^\s+|[^A-Za-z\s]+/g, '').toUpperCase(); // Allow alphabetical letters and space
                break;
            case 'Lower Case':
                filteredValue = inputValue.replace(/^\s+|[^A-Za-z\s]+/g, '').toLowerCase(); // Allow alphabetical letters and space
                break;
            case 'Init Caps':
                filteredValue = inputValue.replace(/^\s+|[^A-Za-z\s]+/g, '').charAt(0).toUpperCase() + inputValue.replace(/^\s+|[^A-Za-z\s]+/g, '').slice(1).toLowerCase(); // Allow alphabetical letters and space
                break;
            default:
                filteredValue = inputValue;
                break;
        }
        e.target.value = filteredValue;
    };
    // const handleInputChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    //   const inputValue = e.target.value;
    //   let filteredValue = inputValue;
    //   if (pattern) {
    //     filteredValue = inputValue.replace(pattern, '').slice(0,maxLength);
    //   }
    //   e.target.value = filteredValue.slice(0,maxLength);
    // };
    return (<div className="flex items-center space-x-2 relative">
         {/* <div className="relative"> */}
      <input type={type === "password" ? (showPassword ? "text" : "password") : type} minLength={minLength} maxLength={maxLength} className={cn("flex-1 h-10 w-full rounded-md border border-input bg-background px-3 py-2 text-sm ring-offset-background file:border-0 file:bg-transparent file:text-sm file:font-medium placeholder:text-muted-foreground focus-visible:outline-none focus-visible:ring-2 focus-visible:ring-ring focus-visible:ring-offset-2 disabled:cursor-not-allowed disabled:opacity-50", className)} ref={ref} onInput={handleInputChange} {...props}/>
      {type === "password" && (<span onClick={() => setShowPassword(prev => !prev)} className="absolute top-1/2 transform -translate-y-1/2 right-14 cursor-pointer" style={{ marginRight: "-35px" }}>
          {showPassword ? <FontAwesomeIcon icon={faEye}/> : <FontAwesomeIcon icon={faEyeSlash}/>}
        </span>)}
    {/* </div> */}
        {/* {info && (
          <TooltipViwer info={info} />
        )} */}
      </div>);
});
Input.displayName = "Input";
export { Input };
