import { __awaiter } from "tslib";
import React, { useEffect, useRef, useState } from 'react';
import { VIEWS, } from 'pasubot-auth-ui-shared';
import { Anchor, Button, Container, Input, Label, Message, } from '../../UI/index.js';
function EmailAuth({ authView = 'sign_in', defaultEmail = '', defaultPassword = '', setAuthView = () => { }, setDefaultEmail = (email) => { }, setDefaultPassword = (password) => { }, supabaseClient, showLinks = false, redirectTo, additionalData, magicLink, i18n, appearance, passwordLimit = false, children, }) {
    var _a, _b, _c, _d;
    const isMounted = useRef(true);
    const [email, setEmail] = useState(defaultEmail);
    const [password, setPassword] = useState(defaultPassword);
    const [error, setError] = useState('');
    const [loading, setLoading] = useState(false);
    const [message, setMessage] = useState('');
    useEffect(() => {
        isMounted.current = true;
        setEmail(defaultEmail);
        setPassword(defaultPassword);
        return () => {
            isMounted.current = false;
        };
    }, [authView]);
    const handleSubmit = (e) => __awaiter(this, void 0, void 0, function* () {
        var _e;
        e.preventDefault();
        setError('');
        setLoading(true);
        switch (authView) {
            case 'sign_in':
                const { error: signInError } = yield supabaseClient.auth.signInWithPassword({
                    email,
                    password,
                });
                if (signInError)
                    setError(signInError.message);
                break;
            case 'sign_up':
                if (passwordLimit && password.length > 72) {
                    setError('Password exceeds maxmium length of 72 characters');
                    return;
                }
                let options = {
                    emailRedirectTo: redirectTo,
                };
                if (additionalData) {
                    options.data = additionalData;
                }
                const { data: { user: signUpUser, session: signUpSession }, error: signUpError, } = yield supabaseClient.auth.signUp({
                    email,
                    password,
                    options,
                });
                if (signUpError)
                    setError(signUpError.message);
                // Check if session is null -> email confirmation setting is turned on
                else if (signUpUser && !signUpSession)
                    setMessage((_e = i18n === null || i18n === void 0 ? void 0 : i18n.sign_up) === null || _e === void 0 ? void 0 : _e.confirmation_text);
                break;
        }
        /*
         * it is possible the auth component may have been unmounted at this point
         * check if component is mounted before setting a useState
         */
        if (isMounted.current)
            setLoading(false);
    });
    const handleViewChange = (newView) => {
        setDefaultEmail(email);
        setDefaultPassword(password);
        setAuthView(newView);
    };
    const labels = i18n === null || i18n === void 0 ? void 0 : i18n[authView];
    return (<form id={authView === 'sign_in' ? `auth-sign-in` : `auth-sign-up`} onSubmit={handleSubmit} autoComplete={'on'} style={{ width: '100%' }}>
      <Container direction="vertical" gap="large" appearance={appearance}>
        <Container direction="vertical" gap="large" appearance={appearance}>
          <div>
            <Label htmlFor="email" appearance={appearance}>
              {labels === null || labels === void 0 ? void 0 : labels.email_label}
            </Label>
            <Input id="email" type="email" name="email" placeholder={labels === null || labels === void 0 ? void 0 : labels.email_input_placeholder} defaultValue={email} onChange={(e) => setEmail(e.target.value)} autoComplete="email" appearance={appearance}/>
          </div>
          <div>
            <Label htmlFor="password" appearance={appearance}>
              {labels === null || labels === void 0 ? void 0 : labels.password_label}
            </Label>
            <Input id="password" type="password" name="password" placeholder={labels === null || labels === void 0 ? void 0 : labels.password_input_placeholder} defaultValue={password} onChange={(e) => setPassword(e.target.value)} autoComplete={authView === 'sign_in' ? 'current-password' : 'new-password'} appearance={appearance}/>
          </div>
          {children}
        </Container>

        <Button type="submit" color="primary" loading={loading} appearance={appearance}>
          {loading ? labels === null || labels === void 0 ? void 0 : labels.loading_button_label : labels === null || labels === void 0 ? void 0 : labels.button_label}
        </Button>

        {showLinks && (<Container direction="vertical" gap="small" appearance={appearance}>
            {authView === VIEWS.SIGN_IN && magicLink && (<Anchor href="#auth-magic-link" onClick={(e) => {
                    e.preventDefault();
                    setAuthView(VIEWS.MAGIC_LINK);
                }} appearance={appearance}>
                {(_a = i18n === null || i18n === void 0 ? void 0 : i18n.magic_link) === null || _a === void 0 ? void 0 : _a.link_text}
              </Anchor>)}
            {authView === VIEWS.SIGN_IN && (<Anchor href="#auth-forgot-password" onClick={(e) => {
                    e.preventDefault();
                    setAuthView(VIEWS.FORGOTTEN_PASSWORD);
                }} appearance={appearance}>
                {(_b = i18n === null || i18n === void 0 ? void 0 : i18n.forgotten_password) === null || _b === void 0 ? void 0 : _b.link_text}
              </Anchor>)}
            {authView === VIEWS.SIGN_IN ? (<Anchor href="#auth-sign-up" onClick={(e) => {
                    e.preventDefault();
                    handleViewChange(VIEWS.SIGN_UP);
                }} appearance={appearance}>
                {(_c = i18n === null || i18n === void 0 ? void 0 : i18n.sign_up) === null || _c === void 0 ? void 0 : _c.link_text}
              </Anchor>) : (<Anchor href="#auth-sign-in" onClick={(e) => {
                    e.preventDefault();
                    handleViewChange(VIEWS.SIGN_IN);
                }} appearance={appearance}>
                {(_d = i18n === null || i18n === void 0 ? void 0 : i18n.sign_in) === null || _d === void 0 ? void 0 : _d.link_text}
              </Anchor>)}
          </Container>)}
      </Container>
      {message && <Message appearance={appearance}>{message}</Message>}
      {error && (<Message color="danger" appearance={appearance}>
          {error}
        </Message>)}
    </form>);
}
export { EmailAuth };
