import { __awaiter } from "tslib";
import React, { useState } from 'react';
import { VIEWS } from 'pasubot-auth-ui-shared';
import { Anchor, Button, Container, Input, Label, Message, } from '../../UI/index.js';
function MagicLink({ setAuthView = () => { }, supabaseClient, redirectTo, i18n, appearance, showLinks = false, }) {
    var _a;
    const [email, setEmail] = useState('');
    const [error, setError] = useState('');
    const [message, setMessage] = useState('');
    const [loading, setLoading] = useState(false);
    const handleMagicLinkSignIn = (e) => __awaiter(this, void 0, void 0, function* () {
        var _b, _c;
        e.preventDefault();
        setError('');
        setMessage('');
        setLoading(true);
        if (email.length === 0) {
            setError((_b = i18n === null || i18n === void 0 ? void 0 : i18n.magic_link) === null || _b === void 0 ? void 0 : _b.empty_email_address);
            setLoading(false);
            return;
        }
        const { error } = yield supabaseClient.auth.signInWithOtp({
            email,
            options: { emailRedirectTo: redirectTo },
        });
        if (error)
            setError(error.message);
        else
            setMessage((_c = i18n === null || i18n === void 0 ? void 0 : i18n.magic_link) === null || _c === void 0 ? void 0 : _c.confirmation_text);
        setLoading(false);
    });
    const labels = i18n === null || i18n === void 0 ? void 0 : i18n.magic_link;
    return (<form id="auth-magic-link" onSubmit={handleMagicLinkSignIn}>
      <Container gap="large" direction="vertical" appearance={appearance}>
        <div>
          <Label htmlFor="email" appearance={appearance}>
            {labels === null || labels === void 0 ? void 0 : labels.email_input_label}
          </Label>
          <Input id="email" name="email" type="email" autoFocus placeholder={labels === null || labels === void 0 ? void 0 : labels.email_input_placeholder} onChange={(e) => {
            if (setError)
                setError('');
            setEmail(e.target.value);
        }} appearance={appearance}/>
        </div>
        <Button color="primary" type="submit" loading={loading} appearance={appearance}>
          {loading ? labels === null || labels === void 0 ? void 0 : labels.loading_button_label : labels === null || labels === void 0 ? void 0 : labels.button_label}
        </Button>
        {showLinks && (<Anchor href="#auth-sign-in" onClick={(e) => {
                e.preventDefault();
                setAuthView(VIEWS.SIGN_IN);
            }} appearance={appearance}>
            {(_a = i18n === null || i18n === void 0 ? void 0 : i18n.sign_in) === null || _a === void 0 ? void 0 : _a.link_text}
          </Anchor>)}
        {message && <Message appearance={appearance}>{message}</Message>}
        {error && (<Message color="danger" appearance={appearance}>
            {error}
          </Message>)}
      </Container>
    </form>);
}
export { MagicLink };
