import { __awaiter } from "tslib";
import { useState } from 'react';
import { template, } from 'pasubot-auth-ui-shared';
import { Button, Container, Divider } from '../../UI/index.js';
import { Icons } from '../Icons.js';
function SocialAuth({ supabaseClient, socialLayout = 'vertical', providers = ['github', 'google', 'azure'], providerScopes, queryParams, redirectTo, onlyThirdPartyProviders = true, view = 'sign_in', i18n, appearance, }) {
    const [loading, setLoading] = useState(false);
    const [error, setError] = useState('');
    const verticalSocialLayout = socialLayout === 'vertical' ? true : false;
    const currentView = view === 'magic_link' ? 'sign_in' : view;
    const handleProviderSignIn = (provider) => __awaiter(this, void 0, void 0, function* () {
        setLoading(true);
        const { error } = yield supabaseClient.auth.signInWithOAuth({
            provider,
            options: {
                redirectTo,
                scopes: providerScopes === null || providerScopes === void 0 ? void 0 : providerScopes[provider],
                queryParams,
            },
        });
        if (error)
            setError(error.message);
        setLoading(false);
    });
    function handleProviderNameEdgeCases(provider) {
        if (provider === 'linkedin_oidc') {
            return 'LinkedIn';
        }
        return provider;
    }
    function capitalize(word) {
        const lower = word.toLowerCase();
        return word.charAt(0).toUpperCase() + lower.slice(1);
    }
    return (<>
      {providers && providers.length > 0 && (<>
          <Container gap="large" direction="vertical" appearance={appearance}>
            <Container direction={verticalSocialLayout ? 'vertical' : 'horizontal'} gap={verticalSocialLayout ? 'small' : 'medium'} appearance={appearance}>
              {providers.map((provider) => {
                var _a;
                return (<Button key={provider} color="default" loading={loading} onClick={() => handleProviderSignIn(provider)} appearance={appearance}>
                    <Icons provider={provider}/>
                    {verticalSocialLayout &&
                        template((_a = i18n === null || i18n === void 0 ? void 0 : i18n[currentView]) === null || _a === void 0 ? void 0 : _a.social_provider_text, {
                            provider: capitalize(handleProviderNameEdgeCases(provider)),
                        })}
                  </Button>);
            })}
            </Container>
          </Container>
          {!onlyThirdPartyProviders && <Divider appearance={appearance}/>}
        </>)}
    </>);
}
export { SocialAuth };
