import { __awaiter } from "tslib";
import React, { useState } from 'react';
import { Button, Container, Input, Label, Message } from '../../UI/index.js';
function UpdatePassword({ supabaseClient, i18n, appearance, passwordLimit = false, }) {
    const [password, setPassword] = useState('');
    const [error, setError] = useState('');
    const [message, setMessage] = useState('');
    const [loading, setLoading] = useState(false);
    const handlePasswordReset = (e) => __awaiter(this, void 0, void 0, function* () {
        var _a;
        e.preventDefault();
        setError('');
        setMessage('');
        setLoading(true);
        if (passwordLimit && password.length > 72) {
            setError('Password exceeds maxmium length of 72 characters');
            setLoading(false);
            return;
        }
        const { error } = yield supabaseClient.auth.updateUser({ password });
        if (error)
            setError(error.message);
        else
            setMessage((_a = i18n === null || i18n === void 0 ? void 0 : i18n.update_password) === null || _a === void 0 ? void 0 : _a.confirmation_text);
        setLoading(false);
    });
    const labels = i18n === null || i18n === void 0 ? void 0 : i18n.update_password;
    return (<form id="auth-update-password" onSubmit={handlePasswordReset}>
      <Container gap="large" direction={'vertical'} appearance={appearance}>
        <div>
          <Label htmlFor="password" appearance={appearance}>
            {labels === null || labels === void 0 ? void 0 : labels.password_label}
          </Label>
          <Input id="password" name="password" placeholder={labels === null || labels === void 0 ? void 0 : labels.password_input_placeholder} type="password" autoFocus onChange={(e) => setPassword(e.target.value)} appearance={appearance}/>
        </div>
        <Button type="submit" color="primary" loading={loading} appearance={appearance}>
          {loading ? labels === null || labels === void 0 ? void 0 : labels.loading_button_label : labels === null || labels === void 0 ? void 0 : labels.button_label}
        </Button>
        {message && <Message appearance={appearance}>{message}</Message>}
        {error && (<Message color="danger" appearance={appearance}>
            {error}
          </Message>)}
      </Container>
    </form>);
}
export { UpdatePassword };
