import { __awaiter } from "tslib";
import React, { useState } from 'react';
import { VIEWS } from 'pasubot-auth-ui-shared';
import { Anchor, Button, Container, Input, Label, Message, } from '../../UI/index.js';
function VerifyOtp({ setAuthView = () => { }, supabaseClient, otpType = 'email', i18n, appearance, showLinks = false, }) {
    var _a;
    const [email, setEmail] = useState('');
    const [phone, setPhone] = useState('');
    const [token, setToken] = useState('');
    const [error, setError] = useState('');
    const [message, setMessage] = useState('');
    const [loading, setLoading] = useState(false);
    const handleSubmit = (e) => __awaiter(this, void 0, void 0, function* () {
        e.preventDefault();
        setError('');
        setMessage('');
        setLoading(true);
        let verifyOpts = {
            email,
            token,
            type: otpType,
        };
        if (['sms', 'phone_change'].includes(otpType)) {
            verifyOpts = {
                phone,
                token,
                type: otpType,
            };
        }
        const { error } = yield supabaseClient.auth.verifyOtp(verifyOpts);
        if (error)
            setError(error.message);
        setLoading(false);
    });
    const labels = i18n === null || i18n === void 0 ? void 0 : i18n.verify_otp;
    return (<form id="auth-magic-link" onSubmit={handleSubmit}>
      <Container gap="large" direction="vertical" appearance={appearance}>
        {['sms', 'phone_change'].includes(otpType) ? (<div>
            <Label htmlFor="phone" appearance={appearance}>
              {labels === null || labels === void 0 ? void 0 : labels.phone_input_label}
            </Label>
            <Input id="phone" name="phone" type="text" autoFocus placeholder={labels === null || labels === void 0 ? void 0 : labels.phone_input_placeholder} onChange={(e) => setPhone(e.target.value)} appearance={appearance}/>
          </div>) : (<div>
            <Label htmlFor="email" appearance={appearance}>
              {labels === null || labels === void 0 ? void 0 : labels.email_input_label}
            </Label>
            <Input id="email" name="email" type="email" autoFocus placeholder={labels === null || labels === void 0 ? void 0 : labels.email_input_placeholder} onChange={(e) => setEmail(e.target.value)} appearance={appearance}/>
          </div>)}
        <div>
          <Label htmlFor="token" appearance={appearance}>
            {labels === null || labels === void 0 ? void 0 : labels.token_input_label}
          </Label>
          <Input id="token" name="token" type="text" placeholder={labels === null || labels === void 0 ? void 0 : labels.token_input_placeholder} onChange={(e) => setToken(e.target.value)} appearance={appearance}/>
        </div>
        <Button color="primary" type="submit" loading={loading} appearance={appearance}>
          {loading ? labels === null || labels === void 0 ? void 0 : labels.loading_button_label : labels === null || labels === void 0 ? void 0 : labels.button_label}
        </Button>
        {showLinks && (<Anchor href="#auth-sign-in" onClick={(e) => {
                e.preventDefault();
                setAuthView(VIEWS.SIGN_IN);
            }} appearance={appearance}>
            {(_a = i18n === null || i18n === void 0 ? void 0 : i18n.sign_in) === null || _a === void 0 ? void 0 : _a.link_text}
          </Anchor>)}
        {message && <Message appearance={appearance}>{message}</Message>}
        {error && (<Message color="danger" appearance={appearance}>
            {error}
          </Message>)}
      </Container>
    </form>);
}
export { VerifyOtp };
