"use client";
import { __awaiter } from "tslib";
import React from 'react';
import { useState, useEffect } from 'react';
export function RolesList({ supabase }) {
    // State for managing side menu visibility
    const [showSideMenu, setShowSideMenu] = useState(false);
    // State for managing form data
    const [formData, setFormData] = useState({
        name: '', // Initialize with empty string
        description: '', // Initialize with empty string
        type: '', // Initialize with empty string
        is_default: false,
        id: "",
        access_level: undefined
    });
    // State for managing roles
    const [roles, setRoles] = useState([]); // Define the state type as Role[]
    useEffect(() => {
        console.log("ROLE LIST REACHED");
        fetchRoles();
    }, []);
    function fetchRoles() {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { data, error } = yield supabase.auth.rolesList();
                console.log("ROLE LIST REACHED", data);
                if (error) {
                    throw error;
                }
                if (data) {
                    setRoles(data.role.roles);
                }
            }
            catch (error) {
                console.error('Error fetching roles:', error);
            }
        });
    }
    // Function to handle opening side menu
    const handleOpenSideMenu = () => {
        setShowSideMenu(true);
    };
    // Function to handle closing side menu
    const handleCloseSideMenu = () => {
        setShowSideMenu(false);
    };
    // Function to handle form input changes
    const handleInputChange = (e) => {
        const { name, value } = e.target;
        setFormData((prevState) => (Object.assign(Object.assign({}, prevState), { [name]: value // Accessing dynamic property based on input name
         })));
    };
    // Function to handle saving role
    const handleSaveRole = () => __awaiter(this, void 0, void 0, function* () {
        // Add the formData to the roles array
        yield supabase.auth.createRole(formData);
        yield fetchRoles();
        // Reset form data
        setFormData({
            name: '', // Reset to empty string
            description: '', // Reset to empty string
            type: '', // Reset to empty string
            is_default: false,
            id: "",
            access_level: undefined
        });
        // Close side menu
        setShowSideMenu(false);
    });
    const handleChange = (event) => {
        setFormData(Object.assign(Object.assign({}, formData), { type: event.target.value }));
    };
    return (<div className="container">
      <div className="container">
        <div className="button-container">
          <h3><strong>Roles List</strong></h3>
          <button className="add-button" onClick={handleOpenSideMenu}>Add Role</button>
        </div>
        <table className="custom-table">
          <thead>
            <tr>
              <th>Name</th>
              <th>Status</th>
              <th>Type</th>
              <th>Select</th>
            </tr>
          </thead>
          <tbody>
            {roles.map((role, index) => (<tr key={index}>
                <td>{role.name}</td>
                <td>{role.status}</td>
                <td>{role.privilege_type}</td>
                <td><input type="checkbox"/></td>
              </tr>))}
          </tbody>
        </table>
        {showSideMenu && (<div className="side-menu">
            <div className="header-container">
              <h3><strong>Create Role</strong></h3>
              <button className="cancel-button" onClick={handleCloseSideMenu}>Cancel</button>
            </div>
            <form>
              <label>Name:</label>
              <input type="text" name="name" value={formData.name} onChange={handleInputChange}/>
              <label>Description</label>
              <input type="text" name="description" value={formData.description} onChange={handleInputChange}/>
              <label>Role Type:</label>
              <select name="roleType" value={formData.type} onChange={handleChange}>
                <option value="">Select role type</option>
                {roles.map((role) => (<option key={role.name} value={role.name}>{role.name}</option>))}
              </select>
              <button type="button" onClick={handleSaveRole}>Save</button>
            </form>

          </div>)}
        <style>{`
        .container {
          padding: 20px;
        }
        .custom-table {
          width: 100%;
          border-collapse: collapse;
          margin-top: 10px;
          
        }
        .custom-table th, .custom-table td {
          border: 1px solid #ddd;
          padding: 8px;
        }
        .button-container {
            display: flex;
            justify-content: flex-end;
            justify-content: space-between;
          }
          .header-container {
            display: flex;
            align-items: center;
            justify-content: space-between; /* Adjust if you want space between the elements */
          }
        .add-button {
          margin-bottom: 20px;
          background-color: #000000;
          color: #fff;
          border: none;
          padding: 10px 20px;
          border-radius: 5px;
          cursor: pointer;
        }
        .add-button:hover {
          background-color: #000000;
        }
        .side-menu {
            margin-top: 20px;
          position: fixed;
          top: 0;
          right: 0;
          width: 300px;
          background: #fff;
          padding: 20px;
          box-shadow: -2px 0 5px rgba(0, 0, 0, 0.2);
        }
        .cancel-button {
            display: flex;
            align-items: center;
            justify-content: center;
            margin-top: 10px;
            background-color: #dc3545;
            color: #fff;
            border: none;
            padding: 10px 20px;
            border-radius: 5px;
            cursor: pointer;
            height: 30px; 
        }
        .cancel-button:hover {
          background-color: #c82333;
        }
        .side-menu {
            position: fixed;
            top: 30px; /* Added top padding */
            right: 0;
            height: calc(100% - 60px); /* Full height minus top and bottom padding */
            padding-top: 30px; /* Added top padding */
            padding-bottom: 30px; /* Added bottom padding */
            width: 300px;
            background: #fff;
            padding: 20px;
            box-shadow: -2px 0 5px rgba(0, 0, 0, 0.2);
            overflow-y: auto;
          }
          .side-menu h2 {
            margin-top: 0;
          }
          .side-menu h3 {
            margin-top: 0;
          }
          .side-menu form {
            display: flex;
            flex-direction: column;
          }
          .side-menu label {
            margin-top: 10px;
          }
          .side-menu input, .side-menu select {
            margin-top: 5px;
            padding: 8px;
            border: 1px solid #ddd;
            border-radius: 4px;
          }
          .side-menu button {
            margin-top: 20px;
            background-color: #000000;
            color: #fff;
            border: none;
            padding: 10px;
            border-radius: 5px;
            cursor: pointer;
          }
          .side-menu button:hover {
            background-color: #000000;
          }
          .cancel-button {
            margin-top: 10px;
            background-color: #dc3545;
            color: #fff;
            border: none;
            padding: 10px;
            border-radius: 5px;
            cursor: pointer;
          }
          .cancel-button:hover {
            background-color: #c82333;
          }
      `}</style>
      </div>

    </div>);
}
